/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDeveloper
 */

namespace TopCoder.Rules.DependencyMap.View
{
	using System;
	using System.IO;
	using System.Drawing;
	using System.Drawing.Imaging;
	using NUnit.Framework;

    /// <summary>
    /// Unit test fixture for BitMapRenderer.
    ///
    /// Testing of BitMapRenderer verifies it can work separately for directory or file.
    /// </summary>
    [TestFixture]
    public class BitMapRendererUnitTests
    {

        /// <summary>
        /// The dependency to use.
        /// </summary>
        private Dependency dependency = new Dependency("unittest");

        /// <summary>
        /// The SVGRenderer instance to test.
        /// </summary>
        private BitMapRenderer renderer = null;

        /// <summary>
        /// Create a new renderer for each test.
        /// </summary>
        [SetUp]
        protected void SetUp()
        {
            renderer = new BitMapRenderer(PixelFormat.Format24bppRgb);
        }

        /// <summary>
        /// Tests the Format getter to ensure it returns the correct value.
        /// </summary>
        [Test]
        public void Format_Getter()
        {
        	Assertion.AssertEquals("BitMapRenderer.Format returning incorrect value",
        	                       renderer.Format,
        	                       PixelFormat.Format24bppRgb);
        }

        /// <summary>
        /// Tests the Format setter to ensure it sets the variable to the correct value.
        /// </summary>
        [Test]
        public void Format_Setter()
        {
        	renderer.Format = PixelFormat.Format16bppArgb1555;

        	Assertion.AssertEquals("BitMapRenderer.Format not being set properly", renderer.Format, 
        	                       PixelFormat.Format16bppArgb1555);
        }

        /// <summary>
        /// Tests the Image getter to ensure it returns the correct value.
        /// </summary>
        [Test]
        public void Image_Getter()
        {
        	Assertion.AssertEquals("BitMapRenderer.Image returning incorrect value", renderer.Image, 
        	                       null);
        }

        /// <summary>
        /// Tests the Image getter to ensure it returns the correct value after rendering.
        /// </summary>
        [Test]
        public void Image_GetterAfterRender()
        {
        	renderer.GetGraphics(dependency, 1, 1);

        	Assertion.AssertEquals("BitMapRenderer.Image not being created correctly", renderer.Image.Width, 1);
        	Assertion.AssertEquals("BitMapRenderer.Image not being created correctly", renderer.Image.Height, 1);
        	Assertion.AssertEquals("BitMapRenderer.Image not being created correctly", renderer.Image.PixelFormat,
        	                       renderer.Format);
        }
        
        /// <summary>
        /// Test GetGraphics() with null dependency.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void GetGraphics_NullDependency()
        {
            renderer.GetGraphics(null, 1, 1);
        }

        /// <summary>
        /// Test GetGraphics() with a zero width
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void GetGraphics_ZeroWidth()
        {
            renderer.GetGraphics(dependency, 0, 1);
        }

        /// <summary>
        /// Test GetGraphics() with a zero height
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void GetGraphics_ZeroHeight()
        {
            renderer.GetGraphics(dependency, 1, 0);
        }

        /// <summary>
        /// Test GetGraphics() with a negative width
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void GetGraphics_NegativeWidth()
        {
            renderer.GetGraphics(dependency, -5, 1);
        }

        /// <summary>
        /// Test GetGraphics() with a negative height
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void GetGraphics_NegativeHeight()
        {
            renderer.GetGraphics(dependency, 1, -5);
        }
        
    }

}
