/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view.failuretests;

import java.io.File;

import junit.framework.TestCase;

import com.topcoder.rules.dependencymap.view.DependencyRenderer;
import com.topcoder.rules.dependencymap.view.FixedGridLayoutManager;
import com.topcoder.rules.dependencymap.view.RendererException;
import com.topcoder.rules.dependencymap.view.SVGRenderer;
import com.topcoder.rules.dependencymap.view.ShapeFactory;

/**
 * Failure test cases for Dependency.
 *
 * @author TCSDeveloper
 */
public class DependencyRendererTest extends TestCase {
    
    private SVGRenderer svgr = new SVGRenderer(new File("."));
    
    /**
     * Test constructor with null SF.
     */
    public void testCon_Null() {
        try {
            new DependencyRenderer(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }
    
    /**
     * Test constructor with valid input.
     */
    public void testCon_Silent() {
        try {
            new DependencyRenderer(new ShapeFactory());            
        } catch (Exception npe) { throw new RuntimeException("Unexpected runtime exception", npe); }
    }

    
    /**
     * Test add with null DR.
     */
    public void testAdd_Null() {
        try {
            new DependencyRenderer().addDiagramRenderer(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }
    
    /**
     * Test remove with null DR.
     */
    public void testRem_Null() {
        try {
            new DependencyRenderer().removeDiagramRenderer(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }

    /**
     * Test remove with good DR.
     */
    public void testRem_Silent() {
        try {
            if (new DependencyRenderer().removeDiagramRenderer(svgr)) fail("Should not have returned true.");            
        } catch (Exception npe) { fail("Should not have thrown Exception:" + npe.toString()); }
    }

    /**
     * Test remove with null DR.
     */
    public void testSet_Null() {
        try {
            new DependencyRenderer().setLayoutManager(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }
    
    /**
     * Test remove with DR.
     */
    public void testSet_Silent() {
        new DependencyRenderer().setLayoutManager(new FixedGridLayoutManager());
    }
    
    /**
     * Test render with null DR.
     */
    public void testRender_Null() {
        try {
            new DependencyRenderer().render(null);
            fail("Should have thrown NullPointerException.");
        } catch (RendererException re) { fail("RE thrown on null"); }
        catch (NullPointerException npe) { /* expected */ }
    }
}
